@@ -1,4 +1,4 @@
-/* $Id: ftnchek.c,v 1.41 2001/11/03 00:55:37 moniot Exp $
+/* $Id: ftnchek.c,v 1.45 2003/03/20 22:14:02 moniot Exp $
 
 	Main program for Fortran Syntax Checker.
 */
@@ -59,6 +59,7 @@ as the "MIT License."
 #include "ftnchek.h"
 #include "intrins.h"
 #include "options.h"
+#include "utils.h"	/* we use strncasecmp */
 
 #ifdef VMS
 #define unlink(s) remove(s)
@@ -229,6 +230,7 @@ do_action:
 		    srcfile = add_ext(&argv[iarg][argchar],DEF_SRC_EXTENSION);
 		    projfile = new_ext(&argv[iarg][argchar],DEF_PROJ_EXTENSION);
 		    dclfile =  new_ext(&argv[iarg][argchar],DEF_DCL_EXTENSION);
+                    html_filename = new_ext(&argv[iarg][argchar],DEF_HTML_EXTENSION);
 #ifdef VCG_SUPPORT
 				/* Initialize main_filename to 1st file arg */
 		    if(main_filename == (char *)NULL)
@@ -280,6 +282,29 @@ do_action:
 		    dcl_fd = (ANY_DCL_DECLARATIONS() &&  ! project_file_input) ?
 		      fopen(dclfile,"w") : (FILE*)NULL;
 
+                      
+                    /* Create html tree file if requested */
+                    if ( ANY_HTML_DECLARATIONS() && htmlcalltree_filename == NULL &&
+                         print_call_tree && ! project_file_input )
+                        {
+                        /*
+                        *  for lack of a better place, create CallTree.html in the
+                        *  local directory
+                        */
+                        htmlcalltree_filename = "CallTree.html";
+                        htmlcalltree_fd = fopen( htmlcalltree_filename, "w" );
+                        (void)fprintf( htmlcalltree_fd,
+                           "<HTML>\n<HEAD><TITLE>Program Call Tree</TITLE></HEAD>\n<BODY>\n<pre>" );
+                        }
+                     
+                    /* Create an html output file if requested */
+                    html_fd = ( ANY_HTML_DECLARATIONS() && ! project_file_input ) ?
+                       fopen( html_filename, "w" ) : (FILE *)NULL;
+                    if ( html_fd )
+                       fprintf( html_fd, 
+                          "<HTML>\n<HEAD><TITLE>Source %s</TITLE></HEAD>\n<BODY>\n",
+                          srcfile );                        
+
 				/* Always print input .f file name.  If
 				   verbose mode, print .prj file names too.
 				 */
@@ -420,6 +445,13 @@ src_file_in(infile)
 		  (void) fclose(project_fd);
 	}
 
+        if ( html_fd != (FILE *) NULL )
+            {
+            fputs( "</BODY>\n</HTML>\n", html_fd );
+            (void) fclose( html_fd );
+            html_fd = NULL;
+            }
+
 	if ((dcl_declarations) && (dcl_fd != stdout))
 	{
 
@@ -588,6 +620,12 @@ wrapup(VOID)	/* look at cross references, etc. */
 	check_comlists();	/* Look for common block mismatches */
 	check_arglists();	/* Look for subprog defn/call mismatches */
 
+        if ( htmlcalltree_fd ) 
+         { 
+         (void)fprintf( htmlcalltree_fd, "</pre>\n</body>\n</html>\n" );
+         fclose( htmlcalltree_fd ); 
+         htmlcalltree_fd = NULL; 
+         }
 #ifdef DEBUG_GLOBAL_STRINGS
 	if(debug_latest)
 	  print_global_strings();
@@ -728,7 +766,7 @@ has_extension(name,ext)		/* true if name ends in ext */
 
   if( stem_len >= 0 &&
      (name_len-stem_len) == ext_len &&
-     cistrncmp(name+stem_len,ext,ext_len) == 0 )
+     strncasecmp(name+stem_len,ext,ext_len) == 0 )
     return TRUE;
   else
     return FALSE;
