@@ -1,4 +1,4 @@
-/* $Id: ftnchek.h,v 1.76 2001/11/03 00:55:37 moniot Exp $
+/* $Id: ftnchek.h,v 1.86 2003/03/20 22:13:17 moniot Exp $
 
 	Common definitions for Fortran Program Checker
 */
@@ -43,7 +43,7 @@ changes, from the XFree86 Project.
 "This program is free software.  Permission is granted to\n\
 modify it and/or redistribute it, retaining this notice.\n\
 No guarantees accompany this software."
-#define VERSION_NUMBER		"FTNCHEK Version 3.1 May 2001"
+#define VERSION_NUMBER		"FTNCHEK Version 3.2 November 2002"
 #define PATCHLEVEL		"Patch Level 2"
 #define PROJECT_VERSION		"P3" /* Project file format version number */
 
@@ -168,6 +168,10 @@ PROTO(VOID exit,(int));
 		/* define default declaration-file extension */
 #ifndef DEF_DCL_EXTENSION
 #define DEF_DCL_EXTENSION ".dcl"
+#endif
+		/* define default html documentation-file extension */
+#ifndef DEF_HTML_EXTENSION
+#define DEF_HTML_EXTENSION ".html"
 #endif
 		/* define default include-file extension */
 #ifndef DEF_INC_EXTENSION
@@ -312,6 +316,16 @@ PROTO(VOID exit,(int));
 #define F95_ALL 1
 #else
 #define F95_ALL 0
+#endif
+
+			/* -mkhtml requires regex support.  This macro
+			   controls only whether the -mkhtml command-line
+			   option is made available.  The relevant variables
+			   and make_html function are still defined, but the
+			   latter (if somehow invoked) just apologizes.
+			 */
+#if HAVE_REGEX_H
+#define HTML_OPTION
 #endif
 
 			/* -portability options default to PORT_ALL.  Define
@@ -641,6 +655,9 @@ PROTO(VOID exit,(int));
 #ifndef REF_LISTS_SIZE 
 #define REF_LISTS_SIZE 200   /* SMALL_MACHINE Lab_ref_lists per chunk*/
 #endif
+#ifndef IO_UNIT_INFO_SIZE
+#define IO_UNIT_INFO_SIZE 50	/* SMALL_MACHINE initial size of I/O unit info table */
+#endif
  
 #else  /* end if SMALL_MACHINE */
 
@@ -688,6 +705,9 @@ PROTO(VOID exit,(int));
 #ifndef REF_LISTS_SIZE 
 #define REF_LISTS_SIZE 400  /* MEDIUM_MACHINE Lab_ref_lists per chunk*/
 #endif
+#ifndef IO_UNIT_INFO_SIZE
+#define IO_UNIT_INFO_SIZE 200	/* MEDIUM_MACHINE initial size of I/O unit info table */
+#endif
 #else		/* Default is now LARGE_MACHINE, OK for most modern machines */
 
 #ifndef HASHSZ		/* must be <= max int  */
@@ -732,6 +752,9 @@ PROTO(VOID exit,(int));
 #ifndef REF_LISTS_SIZE 
 #define REF_LISTS_SIZE 2000  /* LARGE_MACHINE Lab_ref_lists per chunk*/
 #endif
+#ifndef IO_UNIT_INFO_SIZE
+#define IO_UNIT_INFO_SIZE 500	/* LARGE_MACHINE initial size of I/O unit info table */
+#endif
 #endif /* end if LARGE_MACHINE else */
 
 #endif/*end if SMALL_MACHINE else*/
@@ -801,11 +824,15 @@ SHARED FILE
             *input_fd,  /* Input file */
             *list_fd,	/* Output file for listing */
 	    *dcl_fd,	/* Output type declaration file */
+            *html_fd,   /* Output file for HTML documentation */
+            *htmlcalltree_fd, /* Output file for html call tree documentation */
 #ifdef VCG_SUPPORT
 	    *vcg_fd,	/* Output VCG graph description file */
 #endif
 	    *project_fd;/* Project file for symtab info summary */
 
+SHARED char *html_filename;     /* name of the html documentation file */
+SHARED char *htmlcalltree_filename;  /* name of the html call tree doc file */
 SHARED char *current_filename,	/* name of current input file */
 	    *top_filename;	/* name of toplevel parent input file */
 SHARED int incdepth;
@@ -887,6 +914,7 @@ OPT(int,f77_format_extensions,F77_ALL);
 OPT(int,f77_function_noparen,F77_ALL);
 OPT(int,f77_implicit_none,F77_ALL);
 OPT(int,f77_include,F77_ALL);
+OPT(int,f77_initializers,F77_ALL);
 OPT(int,f77_inline_comment,F77_ALL);
 OPT(int,f77_internal_list_io,F77_ALL);
 OPT(int,f77_intrinsics,F77_ALL);
@@ -924,6 +952,7 @@ OPT(int,f90_double_complex,F90_ALL);
 OPT(int,f90_format_dollarsigns,F90_ALL);
 OPT(int,f90_format_extensions,F90_ALL);
 OPT(int,f90_function_noparen,F90_ALL);
+OPT(int,f90_initializers,F90_ALL);
 OPT(int,f90_intrinsics,F90_ALL);
 OPT(int,f90_io_keywords,F90_ALL);
 OPT(int,f90_mixed_expr,F90_ALL);
@@ -949,7 +978,6 @@ OPT(int,f95_assign,F95_ALL);	/* ASSIGN stmt & kin */
 OPT(int,f95_Hedit,F95_ALL);	/* H edit descriptor */
 		/* End of -f95 options */
 
-
 		/* These options are controlled by -makedcls */
 OPT(int,dcl_declarations,FALSE);
 OPT(int,dcl_only_undeclared,FALSE);
@@ -964,6 +992,18 @@ OPT(int,dcl_no_array_dimensions,FALSE);
 OPT(int,dcl_free_form,FALSE);
 		/* End of -makedcls options */
 
+		/* These options are controlled by -mkhtml */
+OPT(int,html_documents,FALSE);
+OPT(int,html_only_undeclared,FALSE);
+OPT(int,html_compact,FALSE);
+OPT(int,html_use_continuations,FALSE);
+OPT(int,html_keywords_lowercase,FALSE);
+OPT(int,html_vars_and_consts_lowercase,FALSE);
+OPT(int,html_excl_sftran3_internal_vars,FALSE);
+OPT(int,html_no_array_dimensions,FALSE);
+OPT(int,html_free_form,FALSE);
+		/* End of -makedcls options */
+
 		/* These options are controlled by -portability */
 OPT(int,port_common_alignment,PORT_ALL);/* Common not in desc size order */
 OPT(int,port_backslash,PORT_ALL); 	/* Backslash used in standard way */
@@ -1157,6 +1197,15 @@ OPT(int,wrap_column,WRAP_COLUMN);/* For wrapping error messages */
   ||dcl_no_array_dimensions\
   ||dcl_free_form\
 )
+#define ANY_HTML_DECLARATIONS() (html_documents\
+  ||html_only_undeclared\
+  ||html_compact||html_use_continuations\
+  ||html_keywords_lowercase\
+  ||html_vars_and_consts_lowercase\
+  ||html_excl_sftran3_internal_vars\
+  ||html_no_array_dimensions\
+  ||html_free_form\
+)
 
 		/* Declare variables for commandline StrSettings */
 OPT(char*,out_fname,(char *)NULL);	/* Output filename */
@@ -1301,4 +1350,3 @@ PROTO(void print_sizeofs, ( void ));
 /* Misc. useful defines */
 #undef MAX
 #define MAX(X,Y) ((X)>(Y)?(X):(Y))
-
