@@ -1,4 +1,4 @@
-/*   $Id: labels.c,v 1.18 2001/11/18 17:05:36 moniot Exp $
+/*   $Id: labels.c,v 1.19 2002/11/20 23:13:47 moniot Rel $
  *   Handles defs and refs of statement labels
  *
  *   Written by Heba Elsayed
@@ -569,15 +569,15 @@ void ref_label(Token *t, int type)
 			   that refer to it.
 			*/
 	if(oldbase != ref_lists) {
-	  int i;
-	  for(i=0; i<ref_index; i++) {
-	    if( ref_lists[i].next != NULL ) {
-	      ref_lists[i].next = (ref_lists[i].next-oldbase)+ref_lists;
+	  int j;
+	  for(j=0; j<ref_index; j++) {
+	    if( ref_lists[j].next != NULL ) {
+	      ref_lists[j].next = (ref_lists[j].next-oldbase)+ref_lists;
 	    }
 	  }
-	  for(i=0; i<labtable_size; i++ ) {
-	    if( labtable[i].lab != NO_LABEL && labtable[i].how_used != NULL ) {
-	      labtable[i].how_used = (labtable[i].how_used-oldbase)+ref_lists;
+	  for(j=0; j<labtable_size; j++ ) {
+	    if( labtable[j].lab != NO_LABEL && labtable[j].how_used != NULL ) {
+	      labtable[j].how_used = (labtable[j].how_used-oldbase)+ref_lists;
 	    }
 	  }
 	}
