@@ -1,4 +1,4 @@
-/* $Id: options.c,v 1.29 2001/11/03 00:55:37 moniot Exp $
+/* $Id: options.c,v 1.36 2003/03/20 22:15:42 moniot Exp $
 
 	Definitions of command-line options and routines to set them.
 
@@ -40,6 +40,7 @@ as the "MIT License."
 #include <ctype.h>
 #include "ftnchek.h"
 #include "options.h"	/* Prototypes of external routines defined below */
+#include "utils.h"	/* we use strncasecmp */
 
 
 typedef enum {		/* for isacheck fields.  Used to suppress -nocheck */
@@ -115,6 +116,8 @@ PROTO(PRIVATE void intrinsic_numeric_option,( int value, char *setting_name ));
 
 PROTO(PRIVATE void makedcl_numeric_option, ( int value, char *setting_name ));
 
+PROTO(PRIVATE void mkhtml_numeric_option, ( int value, char *setting_name ));
+
 PROTO(PRIVATE void source_numeric_option, ( int value, char *setting_name ));
 
 PROTO(PRIVATE void usage_numeric_option, ( int value, char *setting_name ));
@@ -470,6 +473,8 @@ PRIVATE WarnOptionList
 				"IMPLICIT NONE statement"},
   {"include",		&f77_include,
 				"INCLUDE statement"},
+  {"initializer",	&f77_initializers,
+				"Variable initializer in declaration"},
   {"inline-comment",	&f77_inline_comment,
 				"Inline comments starting with !"},
   {"internal-list-io",	&f77_internal_list_io,
@@ -556,6 +561,8 @@ PRIVATE WarnOptionList
 /* Note: f90_freeform_space == misc_warn, not controlled here */
   {"function-noparen",	&f90_function_noparen,
 				"FUNCTION defined without parens"},
+  {"initializer",	&f90_initializers,
+				"Variable initializer using / / in declaration"},
   {"intrinsic",		&f90_intrinsics,
 				"Nonstandard intrinsic functions"},
   {"io-keywords",	&f90_io_keywords,
@@ -688,6 +695,41 @@ PRIVATE WarnOptionList
 };
 
 
+               
+			/* makehtmls is not really a warning list,
+			   but it uses the same style of control. */
+
+PRIVATE char *mkhtml_warn_list=(char *)NULL; /* Make-declarations options */
+
+PRIVATE WarnOptionList
+ mkhtml_warn_option[]={
+  {"none"			/* used by -help */
+     , (int *)NULL,		"Make HTML Documents"}, /* Title for list */
+
+  {"compact",		&html_compact,
+				"compact output format"},
+  {"documents",		&html_documents,
+				"produce html documents"},
+  {"exclude-sftran3",	&html_excl_sftran3_internal_vars,
+				"omit SFTRAN3 internal variables"},
+  {"free-form",		&html_free_form,
+				"produce declarations in free form"},
+  {"keywords-lowercase",&html_keywords_lowercase,
+				"output keywords in lowercase"},
+  {"suppress-array-dimensions",&html_no_array_dimensions,
+				"do not declare array dimensions"},
+#if 0
+  {"undeclared-only",	&html_only_undeclared,
+				"declare only undeclared things"},
+#endif
+  {"use-continuation-lines",&html_use_continuations,
+				" use continuation lines"},
+  {"vars-and-consts-lowercase",&html_vars_and_consts_lowercase,
+				"output variables and constants in lowercase"},
+  {(char *)NULL, (int *)NULL, (char *)NULL},
+};
+
+
 PRIVATE char *port_warn_list=(char *)NULL; /* Nonportable things to warn about */
 
 PRIVATE WarnOptionList
@@ -991,7 +1033,13 @@ PRIVATE StrsettingList strsetting[]={
 			/* makedcls: turnon="declarations" instead of "all" */
   {"makedcls",  &makedcl_warn_list, "declarations", "none", NOT_A_CHECK,
      makedcl_warn_option, makedcl_numeric_option,
-    "make type declaration statements:"},
+    "make type declaration statements"},
+#ifdef HTML_OPTION
+				/* mkhtml similar to makedcls */
+  {"mkhtml",	&mkhtml_warn_list, "documents","none",NOT_A_CHECK,
+     mkhtml_warn_option, mkhtml_numeric_option,
+    "create html documents"},
+#endif
   {"output",	&out_fname,	(char *)NULL, (char *)NULL, NOT_A_CHECK,
      (WarnOptionList *)NULL, NULL,
      "output file name"},
@@ -1107,12 +1155,12 @@ get_env_options(VOID)
 
 				/* setenv nothing or "1" or "YES" --> turnon*/
 	      if(value[0] == '\0'
-		 || cistrncmp(value,"1",strlen(value)) == 0
-		 || cistrncmp(value,"yes",strlen(value)) == 0
+		 || strncasecmp(value,"1",strlen(value)) == 0
+		 || strncasecmp(value,"yes",strlen(value)) == 0
 		 ) {
 		*(strsetting[i].strvalue) = strsetting[i].turnon;
 	      }
-	      else if(cistrncmp(value,"no",strlen(value)) == 0) {
+	      else if(strncasecmp(value,"no",strlen(value)) == 0) {
 		*(strsetting[i].strvalue) = strsetting[i].turnoff;
 	      }
 	      else {		/* Otherwise use the given value */
@@ -1987,6 +2035,32 @@ makedcl_numeric_option( value, setting_name )
  dcl_free_form				= ((value & 0x0400) != 0);
 }
 
+PRIVATE void
+#if HAVE_STDC
+mkhtml_numeric_option( int value, char *setting_name )
+#else
+mkhtml_numeric_option( value, setting_name )
+     int value;
+     char *setting_name;
+#endif
+{
+  /* mkhtml options, old style = sum of numbers as spelled out below */
+  if( value < 0 || value > 0x7ff ) {
+    numeric_option_error(setting_name,0,0x7ff);
+    return;
+  }
+
+ html_documents				= (value != 0);
+ html_only_undeclared			= ((value & 0x0002) != 0);
+ html_compact				= ((value & 0x0004) != 0);
+ html_use_continuations			= ((value & 0x0008) != 0);
+ html_keywords_lowercase		= ((value & 0x0010) != 0);
+ html_vars_and_consts_lowercase		= ((value & 0x0020) != 0);
+ html_excl_sftran3_internal_vars	= ((value & 0x0040) != 0);
+ html_no_array_dimensions		= ((value & 0x0200) != 0);
+ html_free_form				= ((value & 0x0400) != 0);
+}
+
 PRIVATE void
 #if HAVE_STDC
 source_numeric_option( int value, char *setting_name )
@@ -2276,26 +2350,3 @@ append_include_path(new_path)
 #endif
 }
 #endif/*ALLOW_INCLUDE*/
-
-			/* case-insensitive strncmp, since we can't count
-			   on having strncasecmp available.
-			 */
-int
-#if HAVE_STDC
-cistrncmp(const char *s1, const char *s2, unsigned int n)
-#else /* K&R style */
-cistrncmp(s1,s2,n)
-     char *s1,*s2;
-     unsigned n;
-#endif /* HAVE_STDC */
-{
-  while( n != 0 &&
-      (isupper(*s1)?tolower(*s1):*s1) == (isupper(*s2)?tolower(*s2):*s2) ) {
-    if(*s1 == '\0')
-      return 0;
-    if(*s2 == '\0')
-      break;
-    ++s1; ++s2; --n;
-  }
-  return n==0? 0: *s1 - *s2;
-}
