@@ -1,4 +1,4 @@
-/* $Id: symtab.c,v 1.38 2001/11/03 00:50:45 moniot Exp $
+/* $Id: symtab.c,v 1.42 2003/03/26 01:09:22 moniot Exp $
 
   Definitions of symbol table maintenance routines and
   hash table functions
@@ -92,7 +92,6 @@ this Software without prior written authorization from the author.
  call_external(symt,id,arg)	places token list of args into local symtab
  check_intrins_args(arg, defn) Checks call seq of intrinsic functions
  check_stmt_function_args(symt,id,arg)  ditto for statement functions
- find_io_keyword()		Looks up i/o control spec keywords
 */
 
 #include <stdio.h>
@@ -119,7 +118,6 @@ PROTO(PRIVATE Lsymtab* install_local,( int h, int datatype, int storage_class ))
 PROTO(PRIVATE void use_function_arg,( Token *id ));
 PROTO(PRIVATE void use_len_arg,( Token *id ));
 
-PROTO(PRIVATE int find_io_keyword,( char *s ));
 
 
 #ifdef DEBUG_SIZES
@@ -195,7 +193,7 @@ call_func(id,arg)	/* Process function invocation */
 
 
 		/* See if intrinsic.  If so, set flag, save info */
-	if(!symt->external && !symt->intrinsic
+	if(!symt->external && !symt->intrinsic && !symt->argument
 		&& (defn = find_intrinsic(symt->name)) != NULL) {
 			/* First encounter with intrinsic fcn: store info */
 		symt->intrinsic = TRUE;
@@ -1097,12 +1095,10 @@ def_function(datatype,size,size_text,id,args)
 	symt->entry_point = TRUE;
 
 		/* library mode: set the flag so no complaint will
-		   be issued if function never invoked.  Also, set
-		   used_flag if this is a main program, for same reason. */
+		   be issued if function never invoked. */
 	if(library_mode)
 		symt->library_module = TRUE;
 	if(datatype == type_PROGRAM) {
-		symt->used_flag = TRUE;
 #ifdef VCG_SUPPORT		/* Get name of file containing main module */
 		main_filename = top_filename;
 #endif
@@ -1243,7 +1239,8 @@ def_parameter(id,val,noparen)	/* Process parameter_defn_item */
 	   symt->file_declared = inctable_index;
 	}
 	else {			/* protect ourself against nonsense */
-	   if( symt->array_var || symt->external || symt->intrinsic ) {
+	   if( symt->array_var || symt->external || symt->intrinsic 
+	       || symt->entry_point ) {
 	      syntax_error(id->line_num,id->col_num,
 		   "identifier cannot be a parameter:");
 	      msg_tail(symt->name);
@@ -2409,203 +2406,6 @@ use_implied_do_index(id)
 }/*use_implied_do_index*/
 
 
-	/* use_io_keyword handles keyword=value fields in i/o control lists */
-
-#include "iokeywds.h"
-
-void
-#if HAVE_STDC
-use_io_keyword(Token *keyword, Token *value, int stmt_class)
-#else /* K&R style */
-use_io_keyword(keyword,value,stmt_class)
-     Token *keyword,*value;
-     int stmt_class;
-#endif /* HAVE_STDC */
-{
-    unsigned i;
-    int k, stmt_flag=0, type_flag, setit,useit;
-    int hkey=keyword->value.integer;
-    extern int io_internal_file, io_list_directed;/* shared with fortran.y */
-
-		/* Convert statement_class (a token class) into
-		   a bit flag compatible with io_keywords table. */
-    for(i=0; i<NUM_IO_STMTS; i++) {
-	if(local_class[i].stmt_class == stmt_class) {
-	    stmt_flag = local_class[i].stmt_flag;
-	    break;
-	}
-    }
-    if(stmt_flag == 0) {
-      oops_message(OOPS_NONFATAL,keyword->line_num,keyword->col_num,
-	"not an i/o statement class:");
-      (void)fprintf(stderr,"%d",stmt_class);
-      return;
-    }
-		/* Convert value datatype into
-		   a bit flag compatible with io_keywords table.
-		   Note that '*' is handled by using type_UNDECL */
-    if(value->tclass == '*')
-	type_flag = STAR;
-    else
-	type_flag = (1<<datatype_of(value->TOK_type));
-
-				/* Look up keyword in table*/
-    k = find_io_keyword(hashtab[hkey].name);
-
-		/* Not found or nonstandard: issue warning.  A warning is
-		   always given (except under -nocheck) when a keyword
-		   is not recognized, since this can mean something is not
-		   processed correctly.
-		 */
-    if( io_keywords[k].nonstandard
-	|| io_keywords[k].nonf90
-#ifdef ALLOW_VMS_IO /* special VMS case: OPEN(...,NAME=str,...) */
-       || (io_keywords[k].special && stmt_flag==OP)
-#endif /*ALLOW_VMS_IO*/
-	   ) {
-		/* If nonstandard and -f77 or -f90 flag given, issue warning */
-	if( (io_keywords[k].nonstandard && f77_io_keywords)
-	    || (io_keywords[k].nonf90 && f90_io_keywords) ) {
-	  nonstandard(keyword->line_num,keyword->col_num,
-		      (io_keywords[k].nonf90 && f90_io_keywords),0);
-	}
-
-
-	if(io_keywords[k].name == NULL) {
-	    if( f77_io_keywords || f90_io_keywords ) {
-	      /* abbrev warning if nonstd message given */
-		msg_tail(": unrecognized keyword");
-	    }
-	    else {
-	      if(misc_warn) {
-		warning(keyword->line_num,keyword->col_num,
-			"Unrecognized keyword");
-	      }
-	    }
-	    if(f77_io_keywords || f90_io_keywords || misc_warn) {
-	      msg_tail(hashtab[hkey].name);
-	      msg_tail("--  Ftnchek may process incorrectly");
-	    }
-	}
-    }
-
-	/* If label expected, switch integer const to label */
-    if( (LAB & io_keywords[k].allowed_types)
-       &&  (type_flag == INT && is_true(LIT_CONST,value->TOK_flags))) {
-	type_flag = LAB;
-    }
-
-	/*  Now check it out */
-
-
-		/* Check if keyword is allowed with statement */
-
-    if(!(stmt_flag & io_keywords[k].allowed_stmts)) {
-	syntax_error(keyword->line_num,keyword->col_num,
-		     "keyword illegal in this context");
-	return;
-    }
-
-		/* Check if the type is OK */
-
-    if( !(type_flag & io_keywords[k].allowed_types) ) {
-	syntax_error(value->line_num,value->col_num,
-		     "control specifier is incorrect type");
-	return;
-    }
-
-
-	/* Now handle usage */
-
-				/* internal file?: WRITE(UNIT=str,...) */
-    if(stmt_flag == WR && type_flag == CHR
-	    && io_keywords[k].allowed_types == UID) {
-	setit = TRUE;
-	useit = FALSE;
-    }
-				/* INQUIRE: set it if inquire_set flag true */
-    else if(stmt_flag == INQ && io_keywords[k].inquire_set) {
-	setit = TRUE;
-	useit = FALSE;
-    }
-     /* otherwise use use/set flags in table */
-    else {
-	useit = io_keywords[k].implies_use;
-	setit = io_keywords[k].implies_set;
-    }
-
-				/* Keep note if format is '*' */
-    if(value->tclass == '*' && io_keywords[k].allowed_types == FID ) {
-      io_list_directed = TRUE;
-    }
-
-			/* Handle NML=namelist */
-    if(type_flag == NML){
-      ref_namelist(value,stmt_class);
-    }
-
-			/* Handle FMT=format */
-    if(io_keywords[k].allowed_types == FID && type_flag == LAB) {
-      ref_label(value,LAB_IO);
-    }
-
-			/* Handle END=label and ERR=label */
-    if(io_keywords[k].allowed_types == LAB && type_flag == LAB) {
-      ref_label(value,LAB_GOTO);
-      if( style_goto ) {	/* warn if GOTO considered harmful */
-	warning(keyword->line_num,keyword->col_num,
-		"Obsolescent feature: branch to labeled statement");
-      }
-    }
-
-			/* Update usage status if a variable. */
-    if( is_true(ID_EXPR,value->TOK_flags)) {
-	if(useit) {
-	    use_variable(value);
-	}
-	if(setit) {
-	    use_lvalue(value);
-	}
-		/* Character variable as unit id = internal file */
-	if(type_flag == CHR && io_keywords[k].allowed_types == UID) {
-	  io_internal_file = TRUE;
-	}
-    }
-    else if(setit) {		/* if value is set, must be an lvalue */
-	    syntax_error(value->line_num,value->col_num,
-			 "variable required");
-	    return;
-    }
-}
-
-
-		/* Handle VMS OPEN keywords that have no =value */
-void
-#if HAVE_STDC
-use_special_open_keywd(Token *id)
-#else /* K&R style */
-use_special_open_keywd(id)
-     Token *id;
-#endif /* HAVE_STDC */
-{
-#ifdef ALLOW_VMS_IO
-  unsigned i;
-  char *id_name= hashtab[id->value.integer].name;
-
-  for(i=0; i<NUM_SPECIAL_OPEN_KEYWDS; i++) {
-    if(strcmp(id_name,special_open_keywds[i]) == 0) {
-				/* found: report nonstandard if requested */
-      if(f77_io_keywords || f90_io_keywords)
-	nonstandard(id->line_num,id->col_num,f90_io_keywords,0);
-      return;
-    }
-  }
-#endif/*ALLOW_VMS_IO*/
-				/* not found or not VMS: report error */
-  syntax_error(id->line_num,id->col_num,
-	       "Illegal control-list item");
-}
-
 PRIVATE void
 #if HAVE_STDC
 use_len_arg(Token *id)		/* Set the use-flag of arg to intrinsic LEN. */
@@ -2867,28 +2667,6 @@ rehash(hnum)
 
 
 
-	/* find_io_keyword looks up an i/o keyword in io_keywords
-	   table and returns its index.  Uses simple linear search
-	   since not worth hash overhead.  If not found, returns
-	   index of last element of list, which is special. */
-PRIVATE int
-#if HAVE_STDC
-find_io_keyword(char *s)
-             			/* given name */
-#else /* K&R style */
-find_io_keyword(s)
-     char *s;			/* given name */
-#endif /* HAVE_STDC */
-{
-    int i;
-    for(i=0; io_keywords[i].name != NULL; i++) {
-	if(strcmp(io_keywords[i].name, s) == 0) {
-	    break;
-	}
-    }
-    return i;
-}
-
 
 
 #ifdef DEBUG_SIZES
